<?php
/*
Plugin Name: Promotion Slider
Plugin URI: http://www.orderofbusiness.net/plugins/promotion-slider/
Description: This plugin creates a special post type called 'Promotions' that it uses to populate the carousel.  Just use the shortcode [promoslider] to display the slider on your site.  Be sure to check the readme.txt file for more information on what this plugin can really do!
Version: 2.0.0
Author: Micah Wood
Author URI: http://www.orderofbusiness.net/micah-wood/
*/

class promo_slider{
	
	// Define post type that we will pull from
	private $post_type = 'promotion';
	
	function __construct(){
		
		// Create the post type that we will pull from
		include('includes/SD_Register_Post_Type.php');
		$args = array('register_meta_box_cb' => array(&$this, 'meta_box') );
		new SD_Register_Post_Type($this->post_type, $args);
		
		// Initiate key components
		add_action( 'init', array(&$this, 'init') );
	}
	
	function init(){
		
		// Add theme support for post thumbnails
		add_theme_support( 'post-thumbnails' );
		
		// Ensure that jquery is loaded
		wp_enqueue_script( 'jquery' );
		
		// Create [promoslider] shortcode
		add_shortcode( 'promoslider', array(&$this, 'show') );
		
		// Add CSS and jQuery to <head>
	  	add_action( 'wp_head', array(&$this, 'add_to_header') );
		
		// Save meta data when saving promotions
		add_action( 'save_post', array(&$this, 'save_meta_data') );
		
		// Register taxonomy for promotions
		register_taxonomy( 'promotion-categories', array($this->post_type), array(
			'hierarchical' => true,
			'labels' => array( 'name' => __('Categories'),
							  'singular_name' => __('Category'),
							  'search_items' => __('Search Categories'),
							  'all_items' => __('All Categories'),
							  'parent_item' => __('Parent Category'),
							  'parent_item_colon' => __('Parent Category:'),
							  'edit_item' => __('Edit Category'),
							  'update_item' => __('Update Category'),
							  'add_new_item' => __('Add New Category') ),
			'show_ui' => true,
			'query_var' => true,
			'rewrite' => array( 'slug' => 'promotions' )
		));
	}
	
	function show( $atts = array() ){
	  extract($atts);
	  global $post; $tmp_post = $post;
	  $show_posts = array();
	  if( !isset($post_type) || $post_type == 'promotion' ) $show_posts['post_type'] = $this->post_type;
	  else $show_posts['post_type'] = 'post';
	  if( isset($category) && $show_posts['post_type'] == 'promotion' ) $show_posts['promotion-categories'] = $category;
	  elseif( isset($category) && $show_posts['post_type'] == 'post' ) $show_posts['category'] = $category;
      $promo_posts = get_posts( $show_posts ); // Pulls content only from the 'promotion' post type
	  if($promo_posts): $i = 1; ?>
      
      <div <?php if( isset($id) ) echo 'id="'.$id.'" '; ?>class="promo_slider">
        
        <?php foreach($promo_posts as $post): setup_postdata($post);
		  if( !$dest_url = get_post_meta($post->ID, '_promo_slider_url', TRUE) ){ $dest_url = get_permalink(); }
		  if( !$target = get_post_meta($post->ID, '_promo_slider_target', TRUE) ){ $target = '_self'; } ?>
                      
          <div class="panel panel-<?php echo $i; ?>" value="<?php echo $i; ?>">
            <div class="promo_slider_title"><a href="<?php echo $dest_url; ?>" target="<?php echo $target; ?>"><?php the_title(); ?></a></div>
            <div class="promo_slider_excerpt"><?php the_excerpt(); ?></div>
            <div class="promo_slider_background_image"><a href="<?php echo $dest_url; ?>" target="<?php echo $target; ?>"><?php the_post_thumbnail( 'full' ); ?></a></div>
          </div>
            
          <?php $i++; ?>
        <?php endforeach; $post = $tmp_post; ?>
            
        <?php if($i > 2): ?>
          <div class="promo_slider_nav">
            <span class="move_forward pointer" title="Move Backward">&lt;&lt;</span>
            <span class="slider_selections pointer"></span>
            <span class="move_backward pointer" title="Move Forward">&gt;&gt;</span>
          </div>
        <?php endif; ?>
          
        <div class="clear"></div>
          
      </div><?php endif;
    }
	
	function meta_box() {
		add_meta_box( 'promo_slider_meta_box', __('Set Destination URL (Optional)'), array(&$this, 'meta_box_content'), $this->post_type );
	}
	
	function meta_box_content() {
		global $post;
		
		// Use nonce for verification
		wp_nonce_field( plugin_basename(__FILE__), 'promo_slider_noncename' ); 
		
		// The actual fields for data entry  ?>
        <p>If you would like to have the link in the slider point somewhere besides this promotion, enter the desired URL here: <?php print_r($post_id); ?></p>
		<label for="_promo_slider_url"><?php _e('Destination URL: ') ?></label> 
		<input type="text" id= "_promo_slider_url" name="_promo_slider_url" value="<?php $value = get_post_meta($post->ID, '_promo_slider_url', TRUE); if(!empty($value)) echo $value; ?>" size="75" />
        <br />
        <label for="_promo_slider_target">Select the behaviour for this link: </label>
        <?php $target = get_post_meta($post->ID, '_promo_slider_target', TRUE); $selected = ' selected="selected"'; ?>
        <select name="_promo_slider_target">
          <option<?php if( empty($target) ) echo $selected; ?>><?php _e('-- Choose One --'); ?></option>
          <option value="_self"<?php if( $target == '_self' ) echo $selected; ?>><?php _e('Open link in same page'); ?></option>
          <option value="_blank"<?php if( $target == '_blank' ) echo $selected; ?>><?php _e('Open link in a new page'); ?></option>
        </select>
        
	    <?php
	}
	
	function save_meta_data( $post_id ) {

		// Verify this came from our screen and with proper authorization, because save_post can be triggered at other times
	  	if ( !wp_verify_nonce( $_POST['promo_slider_noncename'], plugin_basename(__FILE__) )) { return $post_id; }

		// Verify if this is an auto save routine. If it is, our form has not been submitted, so we don't want to do anything
		if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) return $post_id;
		
		// Check permissions
		  // Is post type correct?
		  if ( $this->post_type != $_POST['post_type'] ) return $post_id;
		  // Can user edit this post?
		  if ( !current_user_can('edit_post', $post_id) ) return $post_id;
	  
		// OK, we're authenticated - find and save the data		
		$data = array('_promo_slider_url', '_promo_slider_target');
		
		foreach($data as $meta){
			$current = get_post_meta($post_id, $meta, TRUE);
			$new = $_POST[$meta];
			
			if( $current && is_null($new) ) delete_post_meta($post_id, $meta);
			else update_post_meta($post_id, $meta, $new);
		}
	}
	
	function add_to_header() {
	  echo '<link rel="stylesheet" href="'.get_bloginfo('wpurl').'/wp-content/plugins/promotion-slider/css/slide.css" type="text/css" media="screen" />';
	  echo '<script type="text/javascript" src="'.get_bloginfo('wpurl').'/wp-content/plugins/promotion-slider/includes/promo_slider.js"></script>';
	}
	
}

global $promo_slider;
$promo_slider = new promo_slider();

?>